@@ -10,6 +10,7 @@ compas_rhino
 
     compas_rhino.artists
     compas_rhino.conduits
+    compas_rhino.conversions
     compas_rhino.forms
     compas_rhino.geometry
     compas_rhino.objects
@@ -29,7 +30,7 @@ if compas.RHINO:
     from .utilities import *  # noqa: F401 F403
 
 
-__version__ = '1.10.0'
+__version__ = '1.12.0'
 
 
 PURGE_ON_DELETE = True
@@ -225,4 +226,5 @@ __all_plugins__ = [
     'compas_rhino.install',
     'compas_rhino.uninstall',
     'compas_rhino.artists',
+    'compas_rhino.geometry.curves',
 ]
